.. _communication:

Communication
=============

* `github.com/Hackerfleet <https://github.com/Hackerfleet>`__
* `Twitter.com/hackerfleet <https://twitter.com/hackerfleet>`__
* `Facebook/hackerfleet <https://www.facebook.com/Hackerfleet>`__
* `hackerfleet.soup.io <http://hackerfleet.soup.io/>`__
* `Also on G+ <https://plus.google.com/105528689027070271173>`__
* `irc #hackerfleet on freenode <http://webchat.freenode.net/?randomnick=1&channels=hackerfleet&uio=d4>`__

.. note:: Please be patient when using IRC, responses might take a few hours!
